#[non_exhaustive]pub enum HuggingFaceError {
InvalidInput {
message: String,
},
CacheMiss {
message: String,
},
Incomplete {
message: String,
},
Hub {
message: String,
},
Io {
message: String,
},
}Expand description
An error returned while resolving a model from the Hugging Face Hub.
External transport errors are converted to contextual strings so this type remains stable, cloneable, and comparable.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidInput
A repository, revision, or filename is invalid.
CacheMiss
The requested revision is not present in the selected local cache.
Incomplete
A repository snapshot lacks required runtime files or metadata.
Hub
A Hugging Face API or download operation failed.
Io
A local cache operation failed.