EngineBuilder

Struct EngineBuilder 

pub struct EngineBuilder { /* private fields */ }
Builder for one complete serving engine.

Implementations

Source

impl EngineBuilder

pub fn new(model_path: impl Into<PathBuf>) -> Self

pub fn tokenizer_config_path(self, value: impl Into<PathBuf>) -> Self

pub fn block_size(self, value: u32) -> Self

pub fn num_blocks(self, value: u32) -> Self

pub fn max_model_len(self, value: u32) -> Self

pub fn max_num_seqs(self, value: u32) -> Self

pub fn tool_parser(self, value: impl Into<String>) -> Self

pub fn reasoning_parser(self, value: impl Into<String>) -> Self

pub fn speculative_config(self, value: impl Into<String>) -> Self

pub fn prefix_caching(self, value: Toggle) -> Self

pub fn max_num_batched_tokens(self, value: u32) -> Self

pub fn scheduler(self, value: SchedulerPolicy) -> Self

Selects the native admission queue policy.

Raw and serde chat request JSON can carry a priority field that the native OpenAI-compatible path parses and submits. Direct completion, completion streaming, and Request submissions currently default to priority zero and tie by arrival; caller-selected priorities for those direct APIs require a future C ABI/API change.

pub fn kv_transfer_config(self, value: impl Into<String>) -> Self

pub fn jump_forward(self, value: Toggle) -> Self

pub fn load(self) -> Result<Engine, Error>